require 'rest-client'
require 'json'
require_relative '../domain/client_info_base.rb'
require_relative '../domain/user.rb'
require_relative '../domain/password.rb'
require_relative '../domain/password_base.rb'
require_relative '../domain/application_config.rb'
require_relative 'authentication_service'

class UserService
    @@create_user_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users'
    @@create_update_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/me'
    @@check_email_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/email'
    @@reset_password_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/reset_password'
    @@change_password_url ='https://showoff-rails-react-production.herokuapp.com/api/v1/users/me/password'
    @@show_logged_in_user_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/me'
    @@show_user_id_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/'

    def self.create_user(user)
        user_with_client_info = get_user_with_client_info(user)
        create_user_payload = User.get_payload(user_with_client_info)
        return RestClient::Request.execute(method: :post, url: @@create_user_url,
            payload: create_user_payload, headers: {'Content-Type': 'application/json'})
    end

    def self.update_user(user, bearer_token)
        user_with_client_info = get_user_with_client_info(user)
        update_user_payload = User.get_payload(user_with_client_info)   
        puts update_user_payload     
        return RestClient::Request.execute(method: :put, url: @@create_update_url,
            payload: update_user_payload,
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.check_email(user)
        return RestClient::Request.execute(method: :get, url: @@check_email_url, 
            headers: {'Content-Type': 'application/json', params: {:email => user.email , :client_id => ApplicationConfig.get_client_id, :client_secret => ApplicationConfig.get_client_secret}})
    end

    def self.reset_password(user)
        user_with_client_info = get_user_with_client_info(user)
        reset_password_payload = User.get_payload(user_with_client_info)  
        return RestClient::Request.execute(method: :post, url: @@reset_password_url,
            payload: reset_password_payload,
            headers: {'Content-Type': 'application/json'})
    end

    def self.change_password(password, bearer_token)
        password_base = PasswordBase.new
        password_base.user = password
        change_password_payload = Password.get_payload(password_base)
        puts change_password_payload
        return RestClient::Request.execute(method: :post, url: @@change_password_url,
            payload: change_password_payload,
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.show_logged_in_user(bearer_token)
            return RestClient::Request.execute(method: :get, url: @@show_logged_in_user_url, 
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.show_user_id(user_id, bearer_token)
        url_with_id = @@show_user_id_url + "#{user_id}"
        return RestClient::Request.execute(method: :get, url: url_with_id, 
        headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.get_user_with_client_info(user)
        user_with_client_info = ClientInfoBase.new
        user_with_client_info.client_id = ApplicationConfig.get_client_id
        user_with_client_info.client_secret = ApplicationConfig.get_client_secret
        user_with_client_info.user = user 
        return user_with_client_info
    end   

    # to remove once tested
    def self.create_user_with_client_info
        user = User.new
        user.first_name = "1000"
        user.last_name = "9Murthy"
        #user.password = "password"
  #    user.current_password = "password"
 #       user.new_password = "password123"
       user.date_of_birth = 1464083530
       # user.email = "sachinmurthy56@gmail.com"
        user.image_url = "https://static.thenounproject.com/png/961-200.png"
    
        #user_with_client_info = ClientInfoBase.new
        #user_with_client_info.client_id = "277ef29692f9a70d511415dc60592daf4cf2c6f6552d3e1b769924b2f2e2e6fe"
        #user_with_client_info.client_secret = "d6106f26e8ff5b749a606a1fba557f44eb3dca8f48596847770beb9b643ea352"
        #user_with_client_info.user = user
        return user
    end

end

# to remove once tested
#ApplicationConfig.set_config("277ef29692f9a70d511415dc60592daf4cf2c6f6552d3e1b769924b2f2e2e6fe", "d6106f26e8ff5b749a606a1fba557f44eb3dca8f48596847770beb9b643ea352")
#user = User.new
#user.email = "sachinmurthy93@gmail.com"
#puts userWithClientIfno = UserService.check_email(user)
#user = UserService.create_user_with_client_info
#pass = Password.new
#pass.current_password ="password"
#pass.new_password ="test123"

#puts UserService.change_password(pass, "Bearer e27068fdf956a544de1d26a8e615919989b9f197171143dc12a8e7de11d6afb3")
#puts UserService.update_user(user, "Bearer e27068fdf956a544de1d26a8e615919989b9f197171143dc12a8e7de11d6afb3")
